Where am py?
============

About
-----

``whereampy`` is a terrible play on words (as in "Where am I?") created
as an example utility to show off a simple ``setuptools``/``setup.py``
distribution package.

``mkpkg`` is a small utlity that demonstrates how to use pkg_resources to
load data files out of a package (instead of relying on __file__ or similar
mechanisms).

Usage
-----

whereampy
~~~~~~~~~

Simply run ``whereampy`` from the command line and use the ``--help`` option
for more information.

mkpkg
~~~~~

Assuming you have a ``src`` subdirectory in your home directory::

    localhost:~$ mkpkg -s spam/spam

will create a directory spam containing a skeleton ``setup.py`` file as well
as a subdirectory ``spam`` with an ``__init__.py`` file.

See ``mkpkg --help`` for more options.

History
-------

* 0.4 - Fixed setup.py issues
* 0.3 - Added the --setup option to mkpkg
* 0.2 - Unreleased tag that first added the mkpkg utility
* 0.1 - Initial release of whereampy
